import logging
import requests
import facturacom

LOG = logging.getLogger(__name__)

class ApiWrapper(object):
    """
    Wrapper for API calls
    """
    def __init__(self):
        pass

    @staticmethod
    def api_call(endpoint, data, method='GET', file=False):
        """
        Makes api call
        @param method: type of REST request
        @param endpoint: endpoint to which generate the request
        @param data: payload for request
        """
        headers = {
            'Content-Type': 'application/json',
            'F-API-KEY': facturacom.FACTURACOM_API_KEY,
            'F-SECRET-KEY': facturacom.FACTURACOM_SECRET_KEY,
        }
        url = ApiWrapper.get_url(endpoint)
        if method.lower() == 'post':
            req = requests.post(url, json=data, headers=headers)
        else:
            req = requests.get(url, params=data, headers=headers)

        LOG.debug(req)
        if req.status_code >= 400:
            return req
        elif req.status_code <= 299 and file:
            return req
        else:
            return req.json()

    @staticmethod
    def get_url(endpoint):
        """
        Generates url for API requests
        @param endpoint: endpoint to construct url
        """
        host = facturacom.FACTURACOM_PRODUCTION
        if facturacom.DEBUG:
            host = facturacom.FACTURACOM_SANDBOX

        return "{0}{1}{2}".format(
            host,
            facturacom.FACTURACOM_NAMESPACE,
            endpoint
        )



import logging
import os
from io import BytesIO
from tempfile import NamedTemporaryFile
from facturacom.api_wrapper import ApiWrapper

LOG = logging.getLogger(__name__)

class Cfdi(object):
    """
    Manage cfdi from endpoints
    """
    def __init__(self):
        pass

    @staticmethod
    def list_all():
        """
        Get all cfdi's
        """
        return ApiWrapper.api_call('/v3/cfdi33/list', dict())

    @staticmethod
    def create(data):
        """
        Creates cfdi from api
        """
        return ApiWrapper.api_call('/v3/cfdi33/create', data, 'POST')

    @staticmethod
    def cancel(uid):
        """
        Cancels cfdi from api
        """
        return ApiWrapper.api_call('/v3/cfdi33/%s/cancel' % uid, dict())

    @staticmethod
    def xml(uid):
        """
        Downloads xml cfdi from api
        """
        request = ApiWrapper.api_call('/v3/cfdi33/%s/xml' % uid, dict(), file=True)
        with NamedTemporaryFile(
            prefix='%s_' % uid,
            suffix='.xml',
            delete=False
        ) as temp:
            temp.write(request.content)

            return temp

    @staticmethod
    def pdf(uid):
        """
        Downloads pdf cfdi from api
        """
        request = ApiWrapper.api_call('/v3/cfdi33/%s/pdf' % uid, dict(), file=True)
        with NamedTemporaryFile(
            prefix='%s_' % uid,
            suffix='.pdf',
            delete=False
        ) as temp:
            temp.write(request.content)

            return temp



import logging
from facturacom.api_wrapper import ApiWrapper

LOG = logging.getLogger(__name__)

class Clients(object):
    """
    Manage clients from endpoints
    """
    def __init__(self):
        pass

    @staticmethod
    def list_all():
        """
        Get all Clients
        """
        return ApiWrapper.api_call('/v1/clients', dict())

    @staticmethod
    def find(rfc):
        """
        Gets single client from api
        """
        return ApiWrapper.api_call('/v1/clients/%s' % rfc, dict())

    @staticmethod
    def create(data):
        """
        Creates client from api
        """
        return ApiWrapper.api_call('/v1/clients/create', data, 'POST')

    @staticmethod
    def update(uid, data):
        """
        Updates client from api
        """
        return ApiWrapper.api_call('/v1/clients/%s/update' % uid, data, 'POST')



from setuptools import setup

__version__ = '1.1.0'

setup(
    name='facturacom',
    packages=['facturacom'], # this must be the same as the name above
    version=__version__,
    description='Integracion de factura.com',
    author='Ricardo Tapia',
    author_email='rtapia92@gmail.com',
    url='https://github.com/richipargo/facturacom',
    download_url='https://github.com/richipargo/facturacom/archive/1.0.0.tar.gz',
    keywords=['testing', 'logging', 'example'], # arbitrary keywords
    classifiers=[],
    install_requires=[
        'requests',
    ]
)



"""
Wrapper for the factura.com REST API
"""

DEBUG = False

FACTURACOM_API_KEY = ''
FACTURACOM_SECRET_KEY = ''

FACTURACOM_SANDBOX = 'http://devfactura.in'
FACTURACOM_PRODUCTION = 'https://factura.com'
FACTURACOM_NAMESPACE = '/api'
